local primitives = love.graphics.newShader [[
// Graphic Primitives
// Original by: Brandon Fogerty
// Note: 2D only

extern float time;
extern vec2 screen;
extern vec2 l1;
extern vec2 l2;
extern float lw;

float z     = 0.5;		// does nothing
float lineWidth = 0.005;
vec3 green  = vec3( 0.0, 0.2, 0.0 );
vec3 blue   = vec3( 0.0, 0.0, 0.2 );
vec3 red    = vec3( 1.0, 0.0, 0.0 );
vec3 yellow = vec3( 1.0, 1.0, 0.0 );
vec3 white 	= vec3( 1.0, 1.0, 1.0 );

float drawLine( vec2 c, vec2 p1, vec2 p2, float epsilon )
	{
	vec2 aToB = p2 - p1;
	vec2 aToP = c - p1;

	float t = length( aToP ) / length( aToB );
	if( t < 0.00 || t > 1.0 ) { return 0.00; }

	vec2 p3 = mix( p1, p2, t );	//linear interpolation - 't' is interp value
	if( length( p3 - c ) <= epsilon ) { return 1.0; }

	return 0.00;
	}

float drawTriangle( vec2 p, vec2 a, vec2 b, vec2 c, float epsilon )
	{
	float t = drawLine( p, a, b, epsilon );
	t += drawLine( p, a, c, epsilon );
	t += drawLine( p, b, c, epsilon );

	return step( 1.0, t );
	}

float drawRectangle( vec2 p, vec2 a, vec2 b, vec2 c, vec2 d, float epsilon )
	{
	float t = drawLine( p, a, b, epsilon );
	t += drawLine( p, c, d, epsilon );
	t += drawLine( p, a, c, epsilon );
	t += drawLine( p, b, d, epsilon );

	return step( 1.0, t );
	}

vec4 effect( vec4 color, Image tex, vec2 texCoord, vec2 pixCoord )
	{
	vec2 uv = ( pixCoord.xy / screen.xy ) * 2.0 - 1.0; //(0,0)=>screen center
	uv.x *= screen.x / screen.y;

	vec3 a = vec3( -0.50,  0.25, z );
	vec3 b = vec3(  0.50,  0.25, z );
	vec3 c = vec3(  0.00,  -0.50, z );
	vec2 position = vec2( 0.0, 0.0 );	// center of screen
	float scale = 1.0;

	float ct = cos( time ) * scale;
	float st = sin( time ) * scale;

	mat3 rotationMatrix = mat3( vec3(  ct, -st, z ),
								vec3(  st,  ct, z ),
								vec3( position.xy, scale ) );
	a = rotationMatrix * a;
	b = rotationMatrix * b;
	c = rotationMatrix * c;
	vec3 finalColor = drawTriangle( uv, a.xy, b.xy, c.xy, lineWidth ) * vec3( cos(uv.x), sin(uv.y), 0.00 )*red;

	vec3 f = vec3( -1.25, 0.95, z );	// lower left corner
	finalColor += drawLine( uv, a.xy, f.xy, lineWidth ) * green;
	finalColor += drawLine( uv, b.xy, f.xy, lineWidth ) * green;
	finalColor += drawLine( uv, c.xy, f.xy, lineWidth ) * green;

	vec3 h = vec3( -1.25, -0.95, z );	// upper left corner
	finalColor += drawLine( uv, a.xy, h.xy, lineWidth ) * green;
	finalColor += drawLine( uv, b.xy, h.xy, lineWidth ) * green;
	finalColor += drawLine( uv, c.xy, h.xy, lineWidth ) * green;

	a += vec3( 0.0, -0.25, z );
	b += vec3( 0.0, -0.25, z );
	c = a + vec3( 0.0, -0.25, z );
	vec3 d = b + vec3( 0.0, -0.25, z );
	finalColor += drawRectangle( uv, a.xy, b.xy, c.xy, d.xy, lineWidth ) * yellow;

	vec3 e= vec3( 1.25, 0.95, z );		// lower right corner
	finalColor += drawLine( uv, a.xy, e.xy, lineWidth ) * blue;
	finalColor += drawLine( uv, b.xy, e.xy, lineWidth ) * blue;
	finalColor += drawLine( uv, c.xy, e.xy, lineWidth ) * blue;
	finalColor += drawLine( uv, d.xy, e.xy, lineWidth ) * blue;

	vec3 g= vec3( 1.25, -0.95, z );		// upper right corner
	finalColor += drawLine( uv, a.xy, g.xy, lineWidth ) * blue;
	finalColor += drawLine( uv, b.xy, g.xy, lineWidth ) * blue;
	finalColor += drawLine( uv, c.xy, g.xy, lineWidth ) * blue;
	finalColor += drawLine( uv, d.xy, g.xy, lineWidth ) * blue;

	vec3 p1= vec3( 0.0, -0.3,  z );	// pentagon
	vec3 p2= vec3(-0.3, -0.1,  z );
	vec3 p3= vec3(-0.2,  0.25, z );
	vec3 p4= vec3( 0.2,  0.25, z );
	vec3 p5= vec3( 0.3, -0.1,  z );

	finalColor += drawLine( uv, p1.xy, p2.xy, lineWidth ) * yellow;
	finalColor += drawLine( uv, p2.xy, p3.xy, lineWidth ) * yellow;
	finalColor += drawLine( uv, p3.xy, p4.xy, lineWidth ) * yellow;
	finalColor += drawLine( uv, p4.xy, p5.xy, lineWidth ) * yellow;
	finalColor += drawLine( uv, p5.xy, p1.xy, lineWidth ) * yellow;

	finalColor += drawLine( uv, l1.xy, l2.xy, lw ) * white;

	return vec4( finalColor, 1.0 );

	}
]]
return primitives
